.. toycrypto documentation master file, created by
   sphinx-quickstart on Mon Oct 14 13:01:10 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: /../common/unsafe.rst

Toy cryptographic functions and utilities
==========================================

Some toy (unsafe for actual use) cryptography related utilites.

    
Table of Contents 
------------------

.. toctree::
  :maxdepth: 2

  intro/quickstart
  
  why/index

  modules/index
  
  bibliography
   